<?php

/**
 * @class BrowseController
 * Controls the browsing of the records
 */

//Yii::import('xcruder.components.BaseController');

class BrowseController extends BaseController
{

	public function getViewId() {

		$id = 'browse_' . $_GET['modelClass'] . '_' . $_GET['modelLevel'];
		
		if (isset($_GET['modelPk']))
			$id	.= preg_replace('/"/','',$_GET['modelPk']);
		
		if (isset($_GET['modelRelationName']))
			$id	.= $_GET['modelRelationName'];
		
		return $id;
	}
	
/**
 * Renders the main gridview for browsing records in modelClass
 */
	public function actionIndex()
	{
		//Finding the rows for the grid - may requested for sorting, filtering 
		$filter = XcruderActiveRecord::getModelFromRequestSearch();
		
		$this->renderPartial('index', array(
			'filter'=> $filter,
			'gridColumns' => XcruderHtml::getGridColumns($filter, ''),
			'dataProvider' => XcruderActiveRecord::getSearchDataProvider($filter)
		),false,true);

		if (Yii::app()->request->isAjaxRequest)
			Yii::app()->end();
	}

/**
 * Renders the relateds view (tabview actually)
 */
	public function actionRelated($relatedModelClass=null, $modelRelationName=null)
	{
		$model = XcruderActiveRecord::getModelFromRequestPk();
		$relatedModel = $relatedModelClass::model();		
		$relation = $model->getActiveRelation($modelRelationName);
		$modelRelationClass = get_class($relation);//eg. "CHasManyRelation"

		$relateds = $model->getRelated($modelRelationName);
		//normalize:
		$relateds = XcruderActiveRecord::safeArray($relateds);

		//filtering
		$relateds = XcruderActiveRecord::filterModelArray($relateds, $relatedModelClass);
		//echo '<pre>';print_r($relateds);echo '</pre>';

		//Rendering _related_view
		$attrs = $relatedModel->attributes;
		$keys = array_keys($attrs);

		$this->renderPartial('index', array(
			'filter' => XcruderActiveRecord::getModelFromRequestSearch('relatedModelClass'),
			'gridColumns' => XcruderHtml::getGridColumns($relatedModel, $modelRelationClass),
			'dataProvider' => new CArrayDataProvider(XcruderActiveRecord::safeArray($relateds), array(
				'pagination'=>array(
					'pageSize'=> @Yii::app()->params['pageSize'],
				),
				'sort'=>array(
					'attributes' => $keys
				)
			))
			
		),false,true);

		if (Yii::app()->request->isAjaxRequest)
			Yii::app()->end();
	}

/**
 * Generates ajax tab content URLs for the tabview
 */
	protected function getRelatedTabs($model) {
		if (!@$model)
			return array();
		
		$tabs = array();

		foreach($model->relations() as $key=>$rels) {
			$rel = $model->getActiveRelation($key);
			$tabs['<span class="icon-relation ' . $rels[0] . '">' . $key . '</span>'] = array(
				'ajax' => $this->createUrl('related', array(
						'modelLevel'=>1+$_GET['modelLevel'],
						'modelRelationName'=>$key, 
						'modelRelationClass'=>$rels[0],
						'relatedModelClass' => $rel->className
					))
			);
		}
		
		return $tabs;
	}

/**
 * Renders the relateds view (tabview actually)
 */
	public function actionRelateds()
	{
		//Finding the rows for the grid - may requested for sorting, filtering 
		//$modelClass = @$_GET["modelClass"];
		$model = XcruderActiveRecord::getModelFromRequestPk();
		
		$this->renderPartial('_relateds', array(
			'relatedTabs' => $this->getRelatedTabs($model)
		),false,true);

		if (Yii::app()->request->isAjaxRequest)
			Yii::app()->end();
	}

}
